@@ -1,12 +1,22 @@
 package Tangerine::HookData;
-$Tangerine::HookData::VERSION = '0.14';
+$Tangerine::HookData::VERSION = '0.15';
 use strict;
 use warnings;
-use Mo qw(default);
+use Tangerine::Utils qw/accessor/;
 
-has hooks => [];
-has modules => {};
-has statement => undef;
+sub new {
+    my $class = shift;
+    my %args = @_;
+    bless {
+        _children => $args{children} // [],
+        _hooks => $args{hooks} // [],
+        _modules => $args{modules} // {},
+    }, $class
+}
+
+sub children { accessor _children => @_  }
+sub hooks { accessor _hooks => @_  }
+sub modules { accessor _modules => @_  }
 
 1;
 
@@ -18,7 +28,7 @@ __END__
 
 =head1 NAME
 
-Tangerine::HookData - An envelope for data returned from a hook.
+Tangerine::HookData - An envelope for data returned from a hook
 
 =head1 SYNOPSIS
 
@@ -27,28 +37,28 @@ Tangerine::HookData - An envelope for data returned from a hook.
             'ExtUtils::MakeMaker' => [
                 Tangerine::Occurence->new(
                     line => 3,
-                    version => '6.30'
-                )
+                    version => '6.30',
+                ),
             ],
         },
         hooks => [
             Tangerine::Hook->new(
-                type => 'use',
-                run => \&Tangerine::hook::myhook::run
-            )
+                type => 'compile',
+                run => \&Tangerine::hook::myhook::run,
+            ),
         ],
         statement => [ qw/myhook_statement with_args ;/ ]
     );
 
 =head1 DESCRIPTION
 
-Hooks used this class to encapsulate their results before returning them
-to the Tangerine object.
+Hooks use this class to encapsulate their results before returning them
+to the main Tangerine object.
 
 A hook may return a hash reference of module names pointing to lists of
 L<Tangerine::Occurence> objects, a list reference of L<Tangerine::Hook>
 objects that should be added to the list of hooks to run and a statement
-which should be analysed in the context of the current line.
+which should be parsed in the context of the current line.
 
 =head1 METHODS
 
