@@ -1,10 +1,15 @@
 package Tangerine::Utils;
-$Tangerine::Utils::VERSION = '0.14';
+$Tangerine::Utils::VERSION = '0.15';
 use strict;
 use warnings;
 use Exporter 'import';
 use List::MoreUtils qw(apply);
-our @EXPORT_OK = qw(addoccurence stripquotelike);
+our @EXPORT_OK = qw(accessor addoccurence stripquotelike);
+
+sub accessor {
+    # TODO: This needs checks
+    $_[1]->{$_[0]} = $_[2] ? $_[2] : $_[1]->{$_[0]}
+}
 
 sub stripquotelike {
     my @filtered = map {
@@ -20,7 +25,7 @@ sub stripquotelike {
                 $_
             }
         } grep {
-            $_ if !/^(,|=>|;)$/so
+            1 if !/^(,|=>|;|)$/so
         } apply {
             s/^\s+|\s+$//sgo;
             $_
@@ -50,7 +55,7 @@ __END__
 
 =head1 NAME
 
-Tangerine::Utils - A set of routines used by various L<Tangerine> modules.
+Tangerine::Utils - A set of routines used by various L<Tangerine> modules
 
 =head1 DESCRIPTION
 
@@ -60,6 +65,10 @@ This module exports the various routines used by L<Tangerine> internals.
 
 =over
 
+=item C<accessor>
+
+A helper routine to generate common attribute accessors.
+
 =item C<stripquotelike>
 
 Attempt to sanitise and strip quote-like operators from a list.
