@@ -1,16 +1,14 @@
 package Tangerine::hook::anymoose;
-$Tangerine::hook::anymoose::VERSION = '0.14';
+$Tangerine::hook::anymoose::VERSION = '0.15';
 use 5.010;
 use strict;
 use warnings;
+use parent 'Tangerine::Hook';
 use List::MoreUtils qw(any);
-use Mo;
 use Tangerine::HookData;
 use Tangerine::Occurence;
 use Tangerine::Utils qw(stripquotelike);
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
     if ((any { $s->[0] eq $_ } qw(use no)) &&
@@ -39,7 +37,7 @@ __END__
 
 =head1 NAME
 
-Tangerine::hook::anymoose - Process C<use Any::Moose> statements.
+Tangerine::hook::anymoose - Process C<use Any::Moose> statements
 
 =head1 DESCRIPTION
 
