@@ -1,14 +1,13 @@
 package Tangerine::hook::if;
-$Tangerine::hook::if::VERSION = '0.14';
+$Tangerine::hook::if::VERSION = '0.15';
 use 5.010;
 use strict;
 use warnings;
+use parent 'Tangerine::Hook';
 use List::MoreUtils qw(any);
-use Mo;
 use Tangerine::HookData;
 use Tangerine::Utils qw(stripquotelike);
 
-extends 'Tangerine::Hook';
 
 sub run {
     my ($self, $s) = @_;
