@@ -1,27 +1,25 @@
 package Tangerine::hook::moduleruntime;
-$Tangerine::hook::moduleruntime::VERSION = '0.14';
+$Tangerine::hook::moduleruntime::VERSION = '0.15';
 use 5.010;
 use strict;
 use warnings;
+use parent 'Tangerine::Hook';
 use List::MoreUtils qw(any none);
-use Mo;
 use Tangerine::HookData;
 use Tangerine::Occurence;
 use Tangerine::Utils qw(stripquotelike);
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
     my @routines = qw(require_module use_module use_package_optimistically);
     if ((any { $s->[0] eq $_ } qw(use no)) && scalar(@$s) > 1 &&
         $s->[1] eq 'Module::Runtime') {
         return Tangerine::HookData->new( hooks => [
-                Tangerine::hook::moduleruntime->new(type => 'req') ] );
+                Tangerine::hook::moduleruntime->new(type => 'runtime') ] );
     }
     # NOTE: For the sake of simplicity, we only check for one subroutine
     #       call per statement.
-    if ($self->type eq 'req' && any { my $f = $_; any { $_ eq $f } @$s }
+    if ($self->type eq 'runtime' && any { my $f = $_; any { $_ eq $f } @$s }
         @routines) {
         while (none { $s->[0] eq $_ } @routines) {
             shift @$s;
