@@ -1,26 +1,24 @@
 package Tangerine::hook::mooselike;
-$Tangerine::hook::mooselike::VERSION = '0.14';
+$Tangerine::hook::mooselike::VERSION = '0.15';
 use 5.010;
 use strict;
 use warnings;
+use parent 'Tangerine::Hook';
 use List::MoreUtils qw(any none);
-use Mo;
 use Tangerine::Hook;
 use Tangerine::HookData;
 use Tangerine::Utils qw(stripquotelike);
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
-    if ($self->type eq 'use' && $s->[0] eq 'use' &&
+    if ($self->type eq 'compile' && $s->[0] eq 'use' &&
         scalar(@$s) > 1 && (any { $s->[1] eq $_ } qw(Moose Mouse Moo Mo))) {
         return Tangerine::HookData->new(
                 hooks => [
-                    Tangerine::hook::mooselike->new(type => 'req'),
+                    Tangerine::hook::mooselike->new(type => 'runtime'),
                 ],
             );
-    } elsif ($self->type eq 'req' && any { $s->[0] eq $_ } qw(extends with)) {
+    } elsif ($self->type eq 'runtime' && any { $s->[0] eq $_ } qw(extends with)) {
         if (scalar(@$s) > 2 && none { $s->[2] eq $_ } ('=>', ',', ';')) {
             # Bail out; most likely an indirect object method call
             return
@@ -65,7 +63,7 @@ __END__
 =head1 NAME
 
 Tangerine::hook::mooselike - Detect Moose-like modules being loaded and
-checks for C<extends> and C<with> statements.
+checks for C<extends> and C<with> statements
 
 =head1 DESCRIPTION
 
