@@ -1,13 +1,11 @@
 package Tangerine::hook::package;
-$Tangerine::hook::package::VERSION = '0.14';
+$Tangerine::hook::package::VERSION = '0.15';
 use strict;
 use warnings;
-use Mo;
+use parent 'Tangerine::Hook';
 use Tangerine::HookData;
 use Tangerine::Occurence;
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
     if ($s->[0] eq 'package' && scalar(@$s) > 1) {
@@ -31,11 +29,11 @@ __END__
 
 =head1 NAME
 
-Tangerine::hook::package - Process C<package> statements.
+Tangerine::hook::package - Process C<package> statements
 
 =head1 DESCRIPTION
 
-This is a basic C<prov> type hook, simply looking for C<package> statements.
+This is a basic C<package> type hook, simply looking for C<package> statements.
 
 =head1 SEE ALSO
 
