@@ -1,16 +1,14 @@
 package Tangerine::hook::prefixedlist;
-$Tangerine::hook::prefixedlist::VERSION = '0.14';
+$Tangerine::hook::prefixedlist::VERSION = '0.15';
 use 5.010;
 use strict;
 use warnings;
+use parent 'Tangerine::Hook';
 use List::MoreUtils qw(any);
-use Mo;
 use Tangerine::HookData;
 use Tangerine::Occurence;
 use Tangerine::Utils qw(stripquotelike);
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
     if ((any { $s->[0] eq $_ } qw(use no)) && scalar(@$s) > 2 &&
@@ -46,7 +44,7 @@ __END__
 
 =head1 NAME
 
-Tangerine::hook::prefixedlist - Process simple sub-module lists.
+Tangerine::hook::prefixedlist - Process simple sub-module lists
 
 =head1 DESCRIPTION
 
