@@ -1,13 +1,11 @@
 package Tangerine::hook::require;
-$Tangerine::hook::require::VERSION = '0.14';
+$Tangerine::hook::require::VERSION = '0.15';
 use strict;
 use warnings;
-use Mo;
+use parent 'Tangerine::Hook';
 use Tangerine::HookData;
 use Tangerine::Occurence;
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
     if (scalar(@$s) > 1 && $s->[0] eq 'require') {
@@ -30,11 +28,11 @@ __END__
 
 =head1 NAME
 
-Tangerine::hook::require - Process C<require> statements.
+Tangerine::hook::require - Process C<require> statements
 
 =head1 DESCRIPTION
 
-This is a basic C<req> type hook, simply looking for C<require> statements.
+This is a basic C<runtime> type hook, simply looking for C<require> statements.
 
 =head1 SEE ALSO
 
