@@ -1,15 +1,13 @@
 package Tangerine::hook::testloading;
-$Tangerine::hook::testloading::VERSION = '0.14';
+$Tangerine::hook::testloading::VERSION = '0.15';
 use strict;
 use warnings;
+use parent 'Tangerine::Hook';
 use List::MoreUtils qw/any/;
-use Mo;
 use Tangerine::HookData;
 use Tangerine::Occurence;
 use Tangerine::Utils qw(stripquotelike);
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
     if (scalar(@$s) > 1 && any { $s->[0] eq $_ } qw/require_ok syntax_ok use_ok/) {
@@ -39,12 +37,12 @@ __END__
 =head1 NAME
 
 Tangerine::hook::testloading - Process various test-suite module loading
-statements.
+statements
 
 =head1 DESCRIPTION
 
-Detect <use_ok()> and <require_ok()> subroutine calls.  This is
-C<require>-style dependency.
+Detect <use_ok()> and <require_ok()> subroutine calls.  These are
+C<runtime> dependencies.
 
 =head1 SEE ALSO
 
