@@ -1,15 +1,13 @@
 package Tangerine::hook::tests;
-$Tangerine::hook::tests::VERSION = '0.14';
+$Tangerine::hook::tests::VERSION = '0.15';
 use 5.010;
 use strict;
 use warnings;
+use parent 'Tangerine::Hook';
 use List::MoreUtils qw(any);
-use Mo;
 use Tangerine::Hook;
 use Tangerine::HookData;
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
     if ((any { $s->[0] eq $_ } qw(use no)) && scalar(@$s) > 1 &&
@@ -17,13 +15,13 @@ sub run {
             qw(Test::Inter Test::Modern Test::More Test::Strict))) {
         require Tangerine::hook::testloading;
         return Tangerine::HookData->new( hooks => [
-                Tangerine::hook::testloading->new(type => 'req') ] );
+                Tangerine::hook::testloading->new(type => 'runtime') ] );
     }
     if ((any { $s->[0] eq $_ } qw(use no)) && scalar(@$s) > 1 &&
         $s->[1] eq 'Test::Requires') {
         require Tangerine::hook::testrequires;
         return Tangerine::HookData->new( hooks => [
-                Tangerine::hook::testrequires->new(type => 'req') ] );
+                Tangerine::hook::testrequires->new(type => 'runtime') ] );
     }
     return;
 }
@@ -39,7 +37,7 @@ __END__
 =head1 NAME
 
 Tangerine::hook::tests - Detect testing modules being loaded and
-register additional hooks.
+register additional hooks
 
 =head1 DESCRIPTION
 
