@@ -1,15 +1,13 @@
 package Tangerine::hook::use;
-$Tangerine::hook::use::VERSION = '0.14';
+$Tangerine::hook::use::VERSION = '0.15';
 use 5.010;
 use strict;
 use warnings;
+use parent 'Tangerine::Hook';
 use List::MoreUtils qw(any);
-use Mo;
 use Tangerine::HookData;
 use Tangerine::Occurence;
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
     if (scalar(@$s) > 1 && (any { $s->[0] eq $_ } qw(use no))) {
@@ -38,11 +36,11 @@ __END__
 
 =head1 NAME
 
-Tangerine::hook::use - Process C<use> statements.
+Tangerine::hook::use - Process C<use> statements
 
 =head1 DESCRIPTION
 
-This is a basic C<use> type hook, simply looking for C<use> statements,
+This is a basic C<compile> type hook, simply looking for C<use> statements,
 not doing anything fancy.
 
 =head1 SEE ALSO
