@@ -1,20 +1,18 @@
 package Tangerine::hook::xxx;
-$Tangerine::hook::xxx::VERSION = '0.14';
+$Tangerine::hook::xxx::VERSION = '0.15';
 use 5.010;
 use strict;
 use warnings;
+use parent 'Tangerine::Hook';
 use List::MoreUtils qw(any);
-use Mo;
 use Tangerine::HookData;
 use Tangerine::Occurence;
 use Tangerine::Utils qw/stripquotelike/;
 
-extends 'Tangerine::Hook';
-
 sub run {
     my ($self, $s) = @_;
     if ((any { $s->[0] eq $_ } qw(use no)) &&
-        scalar(@$s) > 2 && $s->[1] eq 'XXX' && $self->type eq 'use') {
+        scalar(@$s) > 2 && $s->[1] eq 'XXX') {
         my $module;
         if ($s->[2] eq '-dumper') {
             $module = 'Data::Dumper';
@@ -40,7 +38,7 @@ __END__
 
 =head1 NAME
 
-Tangerine::hook::xxx - Detect L<XXX> module loading.
+Tangerine::hook::xxx - Detect L<XXX> module loading
 
 =head1 DESCRIPTION
 
